@@ -13,7 +13,7 @@ fi
 cd ../xmlrpc-c
 export CXXFLAGS="-fPIC"
 export CFLAGS="-Wno-error=format-security"
-./configure --prefix=$PWD/install
+./configure --prefix=$PWD/install --enable-libxml2-backend
 make
 make install
 
